@@ -3,18 +3,21 @@ Main interface for ds service type definitions.
 
 Usage::
 
-    from mypy_boto3.ds.type_defs import AttributeTypeDef
+    ```python
+    from mypy_boto3_ds.type_defs import AttributeTypeDef
 
     data: AttributeTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
